function [prdData, info] = predict_Parupeneus_multifasciatus(par, data, auxData)
  
  % unpack par, data, auxData
  cPar = parscomp_st(par); vars_pull(par); 
  vars_pull(cPar);  vars_pull(data);  vars_pull(auxData);
        
  % compute temperature correction factors
  TC = tempcorr(temp.am, T_ref, T_A);
  
% zero-variate data

  % life cycle
  pars_tp = [g; k; l_T; v_Hb; v_Hp];               % compose parameter vector
  [t_p, t_b, l_p, l_b, info] = get_tp(pars_tp, f); % -, scaled times & lengths at f
  
  % birth
  L_b = L_m * l_b;                  % cm, structural length at birth at f
  Lw_b = L_b/ del_M;                % cm, physical length at birth at f
  Ww_b = L_b^3 * (1 + f * w);       % g, wet weight at birth at f 

  % puberty 
  L_p = L_m * l_p;                  % cm, structural length at puberty at f
  Lw_p = L_p/ del_M;                % cm, physical length at puberty at f

  % ultimate
  l_i = f - l_T;                    % -, scaled ultimate length at f
  L_i = L_m * l_i;                  % cm, ultimate structural length at f
  Lw_i = L_i/ del_M;                % cm, ultimate physical length at f
 
  % reproduction
  pars_R = [kap; kap_R; g; k_J; k_M; L_T; v; U_Hb; U_Hp]; % compose parameter vector at T
  RT_i = TC * reprod_rate(L_i, f, pars_R);             % #/d, ultimate reproduction rate at T

  % life span
  pars_tm = [g; l_T; h_a/ k_M^2; s_G];  % compose parameter vector at T_ref
  t_m = get_tm_s(pars_tm, f, l_b);      % -, scaled mean life span at T_ref
  aT_m = t_m/ k_M/ TC;               % d, mean life span at T

  % males
  p_Am_m = z_m * p_M/ kap;             % J/d.cm^2, {p_Am} spec assimilation flux
  E_m_m = p_Am_m/ v;                   % J/cm^3, reserve capacity [E_m]
  g_m = E_G/ (kap* E_m_m);             % -, energy investment ratio
  m_Em_m = y_E_V * E_m_m/ E_G;         % mol/mol, reserve capacity 
  w_m = m_Em_m * w_E/ w_V;             % -, contribution of reserve to weight
  L_mm = v/ k_M/ g_m;                  % cm, max struct length
  pars_tjm = [g_m k l_T v_Hb v_Hp];
  [t_p, t_b, l_p, l_b] = get_tp(pars_tjm, f);
  L_pm = L_mm * l_p; Lw_pm = L_pm/ del_M; % cm, total length at puberty
  L_im = l_i * L_mm; Lw_im = L_im/ del_M;  % cm, ultimate total length

  % pack to output
  prdData.am = aT_m;
  prdData.Lp = Lw_p;
  prdData.Li = Lw_i;
  prdData.Wwb = Ww_b;
  prdData.Ri = RT_i;
  
  % uni-variate data
  % time-length 
  % females
  f = f_tL;
  kT_M = k_M * TC; rT_B = kT_M/ 3/ (1 + f/ g); % 1/d, von Bert growth rate
  L_b = L_m * get_lb([g; k; v_Hb], f);  L_i = L_m * f;
  L = L_i - (L_i - L_b) * exp( - rT_B * tL_f(:,1)); % cm, struc length
  tLw_f = L/ del_M; % cm, fork length
  % males
  rT_Bm = kT_M/ 3/ (1 + f/ g_m); % 1/d, von Bert growth rate
  L_bm = L_mm * get_lb([g_m; k; v_Hb], f);  L_im = L_mm * f;
  L = L_im - (L_im - L_bm) * exp( - rT_Bm * tL_m(:,1)); % cm, struc length
  tLw_m = L/ del_M; % cm, fork length
  
  % length-weight
  LWw_f = (LW_f(:,1) * del_M) .^ 3 * (1 + f * w); % g, wet weight females
  LWw_m = (LW_m(:,1) * del_M) .^ 3 * (1 + f * w_m); % g, wet weight males
  
%% pack to output
  prdData.tL_f = tLw_f;
  prdData.tL_m = tLw_m;
  prdData.LW_f = LWw_f;
  prdData.LW_m = LWw_m;

